@@ -27,12 +27,13 @@ _IS_PYPY = platform.python_implementation() == "PyPy"
 try:
     from typed_ast import ast3
 except ImportError:
-    # Either our python version is too low, or we're on pypy
-    if sys.version_info < (3, 7) or (sys.version_info < (3, 8) and not _IS_PYPY):
+    if sys.version_info < (3, 8) and not _IS_PYPY:
         print(
-            "The typed_ast package is required but not installed.\n"
-            "You can upgrade to Python 3.8+ or install typed_ast with\n"
-            "`python3 -m pip install typed-ast`.",
+            (
+                "The typed_ast package is required but not installed.\n"
+                "You can upgrade to Python 3.8+ or install typed_ast with\n"
+                "`python3 -m pip install typed-ast`."
+            ),
             file=sys.stderr,
         )
         sys.exit(1)
@@ -166,8 +167,6 @@ def parse_single_version(
         # comments separately.
         return ast3.parse(src, filename, feature_version=version[1])
 
-    raise AssertionError("INTERNAL ERROR: Tried parsing unsupported Python version!")
-
 
 def parse_ast(src: str) -> Union[ast.AST, ast3.AST]:
     # TODO: support Python 4+ ;)
